## HIPSOFCOBRA
A python package to compute the HIggs Portal Scalar OFf-diagonal COupling Branching RAtios. 

## Documentation

A brief user manual can be found in the paper cited below. Additionally, the Jupyter notesbook 
hipsofcobra/demos.ipynb gives a basic explanation of the core usage. 

## Citation

If you use hipsofcobra in a publication, please reference the following citation: 

> [Publication pending] 

## Bugs and feature requests

Please submit bugs and feature requests using
[Github's issue system](https://github.com/blackstonep/hipsofcobra/issues).

## Contributors

Maintainer:

- Patrick Blackstone (@blackstonep)

Contributors (in alphabetical order):

- Patrick Blackstone
- Jaume Tarrús Castellà
- Emilie Passemar
- Jure Zupan

## License

hipsofcobra is released under the GNU General Public License.